#################################################################################################
#################################################################################################
####################################### Prepare  Data ###########################################
#################################################################################################
#################################################################################################

#Read defoliation data
defoliation <- read.delim("defoliation_pub.txt")

#Read forest data
for10<-read.delim("forest2010_pub.txt")
for16<-read.delim("forest2016_pub.txt")

#Position along the sampling transect was recorded for every tree in 2010. 
#If 50 trees were recahed before the maximum transect lenght of 50 meters, the total transect lenght is the number of meters recorded for the final stem.
#If fewer than 50 trees were measured, total transect lenght is allways 50 meters

#Creating a unique identifier for every combination of block and transect makes extraction of transect lenght more convenient 
for10$Block.trans <- paste(for10$Block,for10$Transect)
block.trans <- unique(for10$Block.trans)

for10$Meters <- NA
for(i in 1:length(block.trans)){
  for10$Meters[for10$Block.trans %in% block.trans[i]] <-  ifelse(nrow(for10[for10$Block.trans %in% block.trans[i],])==50,max(for10$Station[for10$Block.trans %in% block.trans[i]],na.rm=T),50)
}

#Remove redundant transect position and indexing variables 
for10$Station <- NULL
for10$Block.trans <- NULL

#Add sampling year to forest data
for10$Period<-2010
for16$Period<-2016

#Merge 2010 and 2016 data into a single dataframe
for.all <- rbind(for10,for16)

#Subset to observations for Birch only
for.all <- subset(for.all,Species=="BP")

#Counters for the number of stems in different damage and height categories  
for.all$D        <- ifelse(for.all$Vital=="D",1,0)
for.all$all.live <- ifelse(for.all$Vital=="D",0,1)
for.all$low.live <- ifelse(for.all$Vital %in% c("L","L1","L2","L3") & for.all$Height==1,1,0)

#Aggregate on the transect (stand) level to get sums for counter variables
for.sum  <-aggregate(for.all[,c(10,13:15)], by=list(Period=for.all$Period, Block=for.all$Block, Transect=for.all$Transect), FUN=sum, na.rm=T)

#Total number of stems per stand is now the sum of living and dead stems
for.sum$all.stem <- for.sum$all.live + for.sum$D

#Reduce meters covered per stand to a single value and add this to aggregated datfarme
for.met  <-aggregate(for.all$Meters, by=list(Period=for.all$Period, Block=for.all$Block, Transect=for.all$Transect), FUN=max, na.rm=T)
colnames(for.met)[ncol(for.met)] <- "Meters" 
for.stand <- merge(for.sum,for.met,by=c("Block","Transect","Period"))

#Also need a dataframe with variables on the level of individual trees
#Note that there is just one record of basal sprout category per tree in 2010 (others NA) and one record per stem i 2016 (all similar).
#Taking the mean per tree will produce the correct category on the tree level in both cases
for.tree.mean <-aggregate(for.all[,9],by=list(Period=for.all$Period, Block=for.all$Block, Transect=for.all$Transect, Tree=for.all$Tree, Single=for.all$Single),FUN=mean,na.rm=T)
names(for.tree.mean)[6] <- "Basal"

#Also need the number of living and dead stems per tree
for.tree.sum  <-aggregate(for.all[,c(13:14)],by=list(Period=for.all$Period, Block=for.all$Block, Transect=for.all$Transect, Tree=for.all$Tree),FUN=sum,na.rm=T)

#Merge to a single dataframe
for.tree  <- merge(for.tree.mean,for.tree.sum,by=c("Period","Block","Transect","Tree"))

#0/1 variable for the presence of basal sprouts
for.tree$bas  <- ifelse(for.tree$Basal>0,1,0)

#Creating a unique identifier for every combination of block and transect makes this more convenient 
for.stand$Block.trans<- paste(for.stand$Block,for.stand$Transect)
for.tree$Block.trans <- paste(for.tree$Block, for.tree$Transect)

block.trans <- unique(for.stand$Block.trans)

for(i in 1:length(block.trans)){
  for (j in c(2010,2016)){
    #No sprouts and no live stems
    for.stand$basal.n.d [for.stand$Block.trans==block.trans[i] & for.stand$Period==j] <- nrow(for.tree[for.tree$Block.trans==block.trans[i] & for.tree$Period==j & for.tree$Basal==0 & for.tree$all.live==0 & complete.cases(for.tree$Basal),])
    #No sprouts and live stems
    for.stand$basal.n.l [for.stand$Block.trans==block.trans[i] & for.stand$Period==j] <- nrow(for.tree[for.tree$Block.trans==block.trans[i] & for.tree$Period==j & for.tree$Basal==0 & for.tree$all.live>0  & complete.cases(for.tree$Basal),])
    #Sprouts and no live stems
    for.stand$basal.y.d [for.stand$Block.trans==block.trans[i] & for.stand$Period==j] <- nrow(for.tree[for.tree$Block.trans==block.trans[i] & for.tree$Period==j & for.tree$Basal>0  & for.tree$all.live==0 & complete.cases(for.tree$Basal),])
    #Sprouts and live stems
    for.stand$basal.y.l [for.stand$Block.trans==block.trans[i] & for.stand$Period==j] <- nrow(for.tree[for.tree$Block.trans==block.trans[i] & for.tree$Period==j & for.tree$Basal>0  & for.tree$all.live>0  & complete.cases(for.tree$Basal),])
  }}

#Add mean defoliation across 2001-2010 to stand dataframe
defoliation$meandef <- rowSums(defoliation[,4:13],na.rm=T)/10



for.stand <- merge(for.stand,defoliation[,c(2:3,14)],by=c("Block","Transect"))

#Drop i NDVI on positive scale
for.stand$meandef.pos <- for.stand$meandef*-1

#######################################################################################
#######################################################################################
################### Distribution of stem mortality rate ###############################
#######################################################################################
#######################################################################################


#Proportion of dead stems per transect
for.stand$p.dead <- for.stand$D/for.stand$all.stem 

#Subset to 2010
for.stand.10 <- subset(for.stand,Period==2010)

#There is one stand with no stems > 1.3 m. Assume proportion dead stems is 0
for.stand.10$p.dead[is.nan(for.stand.10$p.dead)] <- 0

#Arcsin square root transform proportions
for.stand.10$trans.d <-asin(sqrt(for.stand.10$p.dead))

#Test if distribution has more than one mode
library(diptest)
dip.test(for.stand.10$trans.d,simulate.p.value=T)

#Optimal Kmeans clustering of transformed mortality rate. The clustering returns the optimal number of clusters based on BIC  
library(Ckmeans.1d.dp)
dam.clust <- Ckmeans.1d.dp(for.stand.10$trans.d,1:4,estimate.k=c("BIC"),y=1)

#Add the clustering result to the stand data for 2010
for.stand.10$dam.clust   <- dam.clust$cluster

#Add clustering to the full dataset
for.stand$dam.clust <- for.stand.10$dam.clust[match(for.stand$Block.trans,for.stand.10$Block.trans)]

#Change terminology of damage cluster
for.stand$dam.clust    <- ifelse(for.stand$dam.clust==1,   "Healthy","Damaged")
for.stand.10$dam.clust <- ifelse(for.stand.10$dam.clust==1,"Healthy","Damaged")

#Summary statistics for the two clusters
range(for.stand.10$p.dead[for.stand.10$dam.clust=="Healthy"])
range(for.stand.10$p.dead[for.stand.10$dam.clust=="Damaged"])

mean(for.stand.10$p.dead[for.stand.10$dam.clust=="Healthy"])
mean(for.stand.10$p.dead[for.stand.10$dam.clust=="Damaged"])

sd(for.stand.10$p.dead[for.stand.10$dam.clust=="Healthy"])
sd(for.stand.10$p.dead[for.stand.10$dam.clust=="Damaged"])

#Make a custom histogram of mortality rates in 2010
breaks <- seq(0,1.571,by=(1.571/12))

#Bin proportion dead into the categories used in the histogram.
for.stand.10$break.cat <- .bincode(for.stand.10$trans.d,breaks=breaks)
for.stand.10$break.cat[is.na(for.stand.10$break.cat)] <- 0

#Make tables of counts per break category
break.tab.all <-table(for.stand.10$break.cat)

#To make x axis on proportion scale, get hold of back-transformed proportions and the aproximate position they will have on the x axis of the barplot     
#Resulting X axis Will not be exact but very close.
data.frame(trans=seq(0.0,1.571,0.01),plot=seq(0,12,by=(12/157)),back=round(sin(seq(0.0,1.571,0.01))^2,3) )

#Put together custom histogram (Fig. 2a) using barplot function
par(mar=c(5,4,1,1))
barplot(break.tab.all,beside=T,space=0,ylim=c(0,45),xaxt="n",las=1,ylab="Frequency",xlab="Stem mortality rate",cex.axis=0.9)
axis(1,c(0,3.53,6.0,8.46,12.0),labels=c("0","0.20","0.50","0.80","1.00"),cex.axis=0.9,tcl=-0.3)
legend("topleft",legend=c("Healthy","Damaged"),pch=22,pt.bg=c("grey95","grey"),cex=0.9,bty="n",pt.cex=1.4)

#######################################################################################
#######################################################################################
####################### Stem mortality rate ~ Defoliation #############################
#######################################################################################
#######################################################################################

library(rddtools)
library(MuMIn)

#Some exploratory plotting. A cutpoint of 4 seems best 
win.graph(8,8)

disc.dat <- data.frame(meandef.pos=for.stand.10$meandef.pos,trans.d=for.stand.10$trans.d)
disc.dat <- disc.dat[order(disc.dat$meandef.pos),]

r.data.0 <- rdd_data(x=disc.dat$meandef.pos,y=disc.dat$trans.d,cutpoint=0)
plot(r.data.0)

r.data.3 <- rdd_data(x=disc.dat$meandef.pos,y=disc.dat$trans.d,cutpoint=3)
plot(r.data.3)

r.data.4 <- rdd_data(x=disc.dat$meandef.pos,y=disc.dat$trans.d,cutpoint=4)
plot(r.data.4)

r.data.5 <- rdd_data(x=disc.dat$meandef.pos,y=disc.dat$trans.d,cutpoint=5)
plot(r.data.5)

r.data.6 <- rdd_data(x=disc.dat$meandef.pos,y=disc.dat$trans.d,cutpoint=6)
plot(r.data.6)

r.data.7 <- rdd_data(x=disc.dat$meandef.pos,y=disc.dat$trans.d,cutpoint=7)
plot(r.data.7)

#Fit models with cutpoints ranging from 0 to 10 and of order 1-3
#Note that we apply a global approach, using all datapoints.
#It would also be possible to use a local approach, 
#using only the datapoints in a certain bandwith around the cutpoint to estimate D (the change in mortality when crossing the cutpoint). 
#This is not suitable for us, since we are interested in the response along the whole range of the defoliation variable. 

#The cutpoints we want to examine
breaks <- seq(0,10,by=1)

y <- rep(NA,length(breaks))
break.dat <- data.frame(order=1,break.pt=breaks,break.size=y,break.l=y,break.u=y,adj.r.squared=y,Aicc=y,parms=y)

for(i in 1:length(breaks)){
  r.data.break <- rdd_data(x=disc.dat$meandef.pos,y=disc.dat$trans.d,cutpoint=breaks[i])
  disc.lm <- rdd_reg_lm(r.data.break,order=1)
  
  break.dat$break.size[i]    <- summary(disc.lm)$coefficients[2,1] 
  break.dat$break.l[i]       <- summary(disc.lm)$coefficients[2,1]-1.96*summary(disc.lm)$coefficients[2,2] 
  break.dat$break.u[i]       <- summary(disc.lm)$coefficients[2,1]+1.96*summary(disc.lm)$coefficients[2,2] 
  break.dat$adj.r.squared[i] <- summary(disc.lm)$adj.r.squared
  break.dat$Aicc[i]          <- AICc(disc.lm)
  break.dat$parms[i]         <- length(summary(disc.lm)$coefficients[,1])
}

break.dat.2 <- data.frame(order=2,break.pt=breaks,break.size=y,break.l=y,break.u=y,adj.r.squared=y,Aicc=y,parms=y)

for(i in 1:length(breaks)){
  r.data.break.2 <- rdd_data(x=disc.dat$meandef.pos,y=disc.dat$trans.d,cutpoint=breaks[i])
  disc.lm <- rdd_reg_lm(r.data.break.2,order=2)
  
  break.dat.2$break.size[i]    <- summary(disc.lm)$coefficients[2,1] 
  break.dat.2$break.l[i]       <- summary(disc.lm)$coefficients[2,1]-1.96*summary(disc.lm)$coefficients[2,2] 
  break.dat.2$break.u[i]       <- summary(disc.lm)$coefficients[2,1]+1.96*summary(disc.lm)$coefficients[2,2] 
  break.dat.2$adj.r.squared[i] <- summary(disc.lm)$adj.r.squared
  break.dat.2$Aicc[i]          <- AICc(disc.lm)
  break.dat.2$parms[i]         <- length(summary(disc.lm)$coefficients[,1])
}

break.dat.3 <- data.frame(order=3,break.pt=breaks,break.size=y,break.l=y,break.u=y,adj.r.squared=y,Aicc=y,parms=y)

for(i in 1:length(breaks)){
  r.data.break.2 <- rdd_data(x=disc.dat$meandef.pos,y=disc.dat$trans.d,cutpoint=breaks[i])
  disc.lm <- rdd_reg_lm(r.data.break.2,order=3)
  
  break.dat.3$break.size[i]    <- summary(disc.lm)$coefficients[2,1] 
  break.dat.3$break.l[i]       <- summary(disc.lm)$coefficients[2,1]-1.96*summary(disc.lm)$coefficients[2,2] 
  break.dat.3$break.u[i]       <- summary(disc.lm)$coefficients[2,1]+1.96*summary(disc.lm)$coefficients[2,2] 
  break.dat.3$adj.r.squared[i] <- summary(disc.lm)$adj.r.squared
  break.dat.3$Aicc[i]          <- AICc(disc.lm)
  break.dat.3$parms[i]         <- length(summary(disc.lm)$coefficients[,1])
}

#Make table summarizing the results 
out <-round(rbind(break.dat,break.dat.2,break.dat.3),2)

#selcted model
disc.lm <- rdd_reg_lm(r.data.4,order=2)

summary(disc.lm)

pred <- predict(disc.lm,se.fit=T)
pred$upper <- pred$fit+1.96*pred$se.fit 
pred$lower <- pred$fit-1.96*pred$se.fit 
pred$meandef.pos <- r.data.4$x

sin(pred$fit[pred$meandef.pos==3.9])^2
sin(pred$fit[pred$meandef.pos==3.9]-1.96*pred$se.fit[pred$meandef.pos==3.9])^2
sin(pred$fit[pred$meandef.pos==3.9]+1.96*pred$se.fit[pred$meandef.pos==3.9])^2

sin(pred$fit[pred$meandef.pos==4.0])^2
sin(pred$fit[pred$meandef.pos==4.0]-1.96*pred$se.fit[pred$meandef.pos==4.0])^2
sin(pred$fit[pred$meandef.pos==4.0]+1.96*pred$se.fit[pred$meandef.pos==4.0])^2

#Change in predicted mortality rate around breakpoint
round((0.53762+1.96*0.10230),2)
round((0.53762-1.96*0.10230),2)

#Plot predictions dfrom selected model
plot(disc.dat$meandef.pos,disc.dat$trans.d,yaxt="n",type="n",ylab="Mortality rate",xlab="Drop in NDVI")
polygon(c(disc.dat$meandef.pos[pred$meandef.pos<4.0],rev(disc.dat$meandef.pos[pred$meandef.pos<4.0])),c((pred$upper[pred$meandef.pos<4.0]),rev((pred$lower[pred$meandef.pos<4.0]))),col="grey90",border=NA)
polygon(c(disc.dat$meandef.pos[pred$meandef.pos>3.9],rev(disc.dat$meandef.pos[pred$meandef.pos>3.9])),c((pred$upper[pred$meandef.pos>3.9]),rev((pred$lower[pred$meandef.pos>3.9]))),col="grey90",border=NA)
lines(disc.dat$meandef.pos[pred$meandef.pos<4.0],pred$fit[pred$meandef.pos<4.0],lwd=2)
lines(disc.dat$meandef.pos[pred$meandef.pos>3.9],pred$fit[pred$meandef.pos>3.9],lwd=2)
lines(c(3.9,4.0),  c(pred$fit[pred$meandef.pos==3.9][1],pred$fit[pred$meandef.pos==4.0]),lty=2)
axis(2,at=c(asin(sqrt(c(0,0.20,0.5,0.8,1)))),labels=c("0","0.20","0.50","0.80","1.00"),las=1,tcl=0.2,cex.axis=0.9)
points(for.stand.10$meandef.pos,for.stand.10$trans.d,pch=21,bg="white",cex=0.8)


#######################################################################################
#######################################################################################
############################ Mixed  Models ############################################
#######################################################################################
#######################################################################################

#######################################################################################
#######################################################################################
############### Some preparations for modelling and plotting ##########################
#######################################################################################
#######################################################################################

#Some helpful things for plotting 
for.stand$num <- NA
for.stand$num[for.stand$dam.clust=="Healthy" & for.stand$Period==2010] <- 1
for.stand$num[for.stand$dam.clust=="Healthy" & for.stand$Period==2016] <- 2
for.stand$num[for.stand$dam.clust=="Damaged" & for.stand$Period==2010] <- 4
for.stand$num[for.stand$dam.clust=="Damaged" & for.stand$Period==2016] <- 5

for.stand$col <- ifelse(for.stand$Period=="2010","white","grey90")

dam.clust <- unique(for.stand$dam.clust)

library(boot)
library(Hmisc)
library(lme4)
library(influence.ME)

#######################################################################################
#######################################################################################
#################### Tree layer variables (stems > 1.3 m)  ############################
#######################################################################################
#######################################################################################

#Coerce damage cluster and period to factor variables
for.stand$dam.clust <- factor(for.stand$dam.clust)
for.stand$Period    <- factor(for.stand$Period)

#Relevel to have healthy forest as reference level 
for.stand$dam.clust <- relevel(for.stand$dam.clust,ref="Healthy")

#Fit negative binomial mixed model with period*damage cluster interaction, an offset for transect length and random intercepts for landscape blocks 
nb.all <- glmer.nb(all.live ~ Period*dam.clust + offset(log(Meters)) +(1|Block), data=for.stand,glmerControl(optimizer="bobyqa", optCtrl = list(maxfun = 10000000))) 
nb.low <- glmer.nb(low.live ~ Period*dam.clust + offset(log(Meters)) +(1|Block), data=for.stand,glmerControl(optimizer="bobyqa", optCtrl = list(maxfun = 10000000))) 

#Check for influential observations by sequential deletion of single observations
inf.all <- influence(nb.all,obs=TRUE)
inf.low <- influence(nb.low,obs=TRUE)

#Check Coocks distance 
round(cooks.distance.estex(inf.all),1)
round(cooks.distance.estex(inf.low),1)

#Which ovservations have large coocks (>1)?
which(cooks.distance.estex(inf.all)>1)
which(cooks.distance.estex(inf.low)>1)

#Check parameter estimates when removing the two influential observations for all stems and compare with estimates when using all observations
inf.all$alt.fixed[which(cooks.distance.estex(inf.all)>1),]
summary(nb.all)

#Removing the influential observations will not change the conclusions from the modelling. Parameter estimates change only slightly 
#Thus, keep these observation in the analysis

#Get parameter estimates. 95% CI presented in paper is taken as estimate +/- 1.96*SE
summary(nb.all)
summary(nb.low)

#Back-transformed model predictions, using the method suggested by Ben Bolker at http://bbolker.github.io/mixedmodels-misc/glmmFAQ.html for obtaining 95% CI. 
#Predict for a 50 m transect, i.e. 100 square meters 
newdat.stem <- expand.grid(Period=unique(for.stand$Period),dam.clust=unique(for.stand$dam.clust),Meters=50,all.live=0,low.live=0)

#Helps with plotting further down
newdat.stem$num <- c(4,5,1,2)  

mm.all  <- model.matrix(terms(nb.all),newdat.stem)
mm.low  <- model.matrix(terms(nb.low),newdat.stem)

newdat.stem$pred.all <- predict(nb.all,newdat.stem,re.form=NA)
newdat.stem$pred.low <- predict(nb.low,newdat.stem,re.form=NA)

pvar.all <- diag(mm.all %*% tcrossprod(vcov(nb.all),mm.all))
pvar.low <- diag(mm.low %*% tcrossprod(vcov(nb.low),mm.low))

cmult <- 1.96

#Back transform predictions to response scale
newdat.stem <- data.frame(
  newdat.stem
  , pred.all.r = exp(newdat.stem$pred.all)
  , pred.low.r = exp(newdat.stem$pred.low)
  , plo.all.r  = exp(newdat.stem$pred.all-cmult*sqrt(pvar.all))
  , phi.all.r  = exp(newdat.stem$pred.all+cmult*sqrt(pvar.all))
  , plo.low.r  = exp(newdat.stem$pred.low-cmult*sqrt(pvar.low))
  , phi.low.r  = exp(newdat.stem$pred.low+cmult*sqrt(pvar.low))
)

#Obtain response ratios for the change between 2010 and 2016
#Relevel to have damaged forest as reference level and refit models (makes it easier to extract odds ratios for damaged forest)
for.stand$dam.clust.re <- relevel(as.factor(for.stand$dam.clust),ref="Damaged")

nb.all.re <- glmer.nb(all.live ~ Period*dam.clust.re + offset(log(Meters)) +(1|Block), data=for.stand, glmerControl(optimizer="bobyqa", optCtrl = list(maxfun = 10000000))) 
nb.low.re <- glmer.nb(low.live ~ Period*dam.clust.re + offset(log(Meters)) +(1|Block), data=for.stand, glmerControl(optimizer="bobyqa", optCtrl = list(maxfun = 10000000))) 

#Make dataframe with response ratios and 95% CI for damaged and healthy forest based on model parameter estimates
resp.frame <- expand.grid(dam.clust = unique(for.stand$dam.clust.re))

resp.frame$resp.all     <- c(exp(summary(nb.all.re)$coef[2,1]),                                   exp(summary(nb.all)$coef[2,1]))
resp.frame$resp.all.plo <- c(exp(summary(nb.all.re)$coef[2,1]-1.96*summary(nb.all.re)$coef[2,2]), exp(summary(nb.all)$coef[2,1]-1.96*summary(nb.all)$coef[2,2]))
resp.frame$resp.all.phi <- c(exp(summary(nb.all.re)$coef[2,1]+1.96*summary(nb.all.re)$coef[2,2]), exp(summary(nb.all)$coef[2,1]+1.96*summary(nb.all)$coef[2,2]))

resp.frame$resp.low     <- c(exp(summary(nb.low.re)$coef[2,1]),                                   exp(summary(nb.low)$coef[2,1]))
resp.frame$resp.low.plo <- c(exp(summary(nb.low.re)$coef[2,1]-1.96*summary(nb.low.re)$coef[2,2]), exp(summary(nb.low)$coef[2,1]-1.96*summary(nb.low)$coef[2,2]))
resp.frame$resp.low.phi <- c(exp(summary(nb.low.re)$coef[2,1]+1.96*summary(nb.low.re)$coef[2,2]), exp(summary(nb.low)$coef[2,1]+1.96*summary(nb.low)$coef[2,2]))

#Helps with plotting further down
resp.frame$num <- c(2,1)

#Plot response ratios and predicted stem counts with raw data in the background (Fig.3) 
par(mfrow=c(2,2))
par(mar=c(0,0,0,0))
par(oma=c(4,4,4,4))

plot(resp.frame$num,resp.frame$resp.low,type="n",xlim=c(0.5,2.5),xaxt="n",las=1,tcl=0.3,cex.axis=1.1,ylim=c(0,2.2))
errbar(x=resp.frame$num,y=resp.frame$resp.low,yplus=resp.frame$resp.low.phi,yminus=resp.frame$resp.low.plo,add=T,cap=0.00,lwd=1,cex=0)
points(resp.frame$num,resp.frame$resp.low,pch=21,cex=2.5,bg="black")
abline(1,0,lty=2,col="grey55")

plot(resp.frame$num,resp.frame$resp.all,type="n",xlim=c(0.5,2.5),xaxt="n",las=1,tcl=0.3,cex.axis=1.1,ylim=c(0,2.2),yaxt="n")
errbar(x=resp.frame$num,y=resp.frame$resp.all,yplus=resp.frame$resp.all.phi,yminus=resp.frame$resp.all.plo,add=T,cap=0.00,lwd=1,cex=0)
abline(1,0,lty=2,col="grey55")
points(resp.frame$num,resp.frame$resp.all,pch=21,cex=2.5,bg="black")

plot(newdat.stem$num,newdat.stem$pred.low.r,ylim=c(0.9,65),type="n",xlim=c(0,6),xaxt="n",las=1,log="y",tcl=0.3,cex.axis=1.1)
points(for.stand$num,jitter(for.stand$low.live,0.5)+1 ,pch=21,bg=for.stand$col,col="grey",cex=1.2)
for(i in 1:2){ 
  arrows(x0=newdat.stem$num[newdat.stem$dam.clust==dam.clust[i] & newdat.stem$Period=="2010"],x1=newdat.stem$num[newdat.stem$dam.clust==dam.clust[i] & newdat.stem$Period=="2016"],
         y0=newdat.stem$pred.low.r[newdat.stem$dam.clust==dam.clust[i] & newdat.stem$Period=="2010"]+1,y1=newdat.stem$pred.low.r[newdat.stem$dam.clust==dam.clust[i] & newdat.stem$Period=="2016"]+1,
         length=0,lwd=1,col="black")}
errbar(x=newdat.stem$num,y=newdat.stem$pred.low.r+1,yplus=newdat.stem$phi.low.r+1,yminus=newdat.stem$plo.low.r+1,add=T,cap=0.00,lwd=1,cex=0)
points(newdat.stem$num,newdat.stem$pred.low.r+1,pch=21,cex=2.5,bg=c("white","grey"))
legend("topright",pch=21,pt.bg=c("white","grey"),legend=c("2010","2016"),pt.cex=2.2)
axis(1,at=c(1.5,4.5),labels=c("Healthy","Damaged"),tcl=0.0,cex.axis=1.1)

plot(newdat.stem$num,newdat.stem$pred.all.r,ylim=c(0.9,65),type="n",xlim=c(0,6),xaxt="n",las=1,log="y",tcl=0.3,cex.axis=1.1,yaxt="n")
points(for.stand$num,jitter(for.stand$all.live,0.5)+1,pch=21,bg=for.stand$col,col="grey",cex=1.2)
for(i in 1:2){ 
  arrows(x0=newdat.stem$num[newdat.stem$dam.clust==dam.clust[i] & newdat.stem$Period=="2010"],x1=newdat.stem$num[newdat.stem$dam.clust==dam.clust[i] & newdat.stem$Period=="2016"],
         y0=newdat.stem$pred.all.r[newdat.stem$dam.clust==dam.clust[i] & newdat.stem$Period=="2010"]+1,y1=newdat.stem$pred.all.r[newdat.stem$dam.clust==dam.clust[i] & newdat.stem$Period=="2016"]+1,
         length=0,lwd=1,col="black")}
errbar(x=newdat.stem$num,y=newdat.stem$pred.all.r+1,yplus=newdat.stem$phi.all.r+1,yminus=newdat.stem$plo.all.r+1,add=T,cap=0.00,lwd=1,cex=0)
points(newdat.stem$num,newdat.stem$pred.all.r+1,pch=21,cex=2.5,bg=c("white","grey"))
axis(1,at=c(1.5,4.5),labels=c("Healthy","Damaged"),tcl=0.0,cex.axis=1.1)

mtext(side=3,"Total # living stems",outer=T,padj=-1,adj=0.80,cex=0.75)
mtext(side=3,"# living stems < 2 m",outer=T,padj=-1,adj=0.15,cex=0.75)

mtext(side=2,"# stems",       outer=T,padj=-3.3,adj=0.15,cex=0.75)
mtext(side=2,"Response ratio",outer=T,padj=-3.3,adj=0.80,cex=0.75)


#######################################################################################
#######################################################################################
#################### Probability of sprouting in individual trees  ####################
#######################################################################################
#######################################################################################

#Note: a few transects had zero stems. To avoid that these get lost during aggregation, they are represented in the data as a single "ghost" birch with zero stems. 
#We need to get rid of these false trees before proceding with the tree-level analysis
#Vector with the block*transect*year combinations that have zero stems
zero <- c("10 2 2016","22 6 2016", "25 9 2016","28 4 2016","30 11 2016","37 1 2016","39 2 2016","45 3 2016","52 13 2016","39 2 2010")

#Make a block*transect*year index in the tree data
for.tree$Block.trans.per <- paste(for.tree$Block,for.tree$Transect,for.tree$Period)

#Now get rid of the zero transects using the index
for.tree.pos <- for.tree[!for.tree$Block.trans.per %in% zero,]

#Compute proportion of living stems per tree
for.tree.pos$all.stem <- for.tree.pos$all.live + for.tree.pos$D 
for.tree.pos$p.live   <- for.tree.pos$all.live/for.tree.pos$all.stem

#Group trees into four vitality categories 
for.tree.pos$vit <- NA
for.tree.pos$vit[for.tree.pos$p.live==0] <- 0
for.tree.pos$vit[for.tree.pos$p.live>0 & for.tree.pos$p.live<=0.33] <- 1 
for.tree.pos$vit[for.tree.pos$p.live>0.33 & for.tree.pos$p.live<=0.66] <- 2
for.tree.pos$vit[for.tree.pos$p.live>0.66] <- 3

#Subset to monocormic and polycormic trees
for.tree.poly <- subset(for.tree.pos,Single=="M")
for.tree.mono <- subset(for.tree.pos,Single=="S")

#Convert vitality category and period into factors
for.tree.poly$vit <- factor(for.tree.poly$vit)
for.tree.mono$vit <- factor(for.tree.mono$vit)
for.tree.poly$Period <- factor(for.tree.poly$Period)
for.tree.mono$Period <- factor(for.tree.mono$Period)

#Fit binomial mixed model of the presence of sprouts (0/1) on the vitality*period interaction, with landscape block and transect within block as random intercepts
polymod <- glmer(bas ~ vit*Period + (1|Block/Transect), family=binomial, data=for.tree.poly, glmerControl(optimizer="bobyqa",optCtrl=list(maxfun = 10000000)))
monomod <- glmer(bas ~ vit*Period + (1|Block/Transect), family=binomial, data=for.tree.mono, glmerControl(optimizer="bobyqa",optCtrl=list(maxfun = 10000000)))

#Check for influential observations by sequential deletion of single observations (takes several hours due to many observations in the dataset) 
inf.poly <- influence(polymod,obs=TRUE)
inf.mono <- influence(monomod,obs=TRUE)

#Check Coocks distance 
round(cooks.distance.estex(inf.poly),1)
round(cooks.distance.estex(inf.mono),1)

#Which ovservations have large coocks (>1)?
which(cooks.distance.estex(inf.poly)>1)
which(cooks.distance.estex(inf.mono)>1)
#No observations are identified as influential

#Get parameter estimates. 95% CI presented in paper is taken as estimate +/- 1.96*SE
summary(polymod)
summary(monomod)

#Get back-transformed model predictions for p(sprouting), using the method suggested by Ben Bolker at http://bbolker.github.io/mixedmodels-misc/glmmFAQ.html for obtaining 95% CI. 
newdat.poly <- expand.grid(Period=factor(c(2010,2016)),vit=factor(c(0:3)),bas=0)
newdat.mono <- expand.grid(Period=factor(c(2010,2016)),vit=factor(c(0,3)),bas=0)

mm.poly    <- model.matrix(terms(polymod),newdat.poly)
mm.mono    <- model.matrix(terms(monomod),newdat.mono)

newdat.poly$pred <- predict(polymod,newdat.poly, re.form=NA)
newdat.mono$pred <- predict(monomod,newdat.mono, re.form=NA)

pvar.poly  <- diag(mm.poly%*% tcrossprod(vcov(polymod), mm.poly))
pvar.mono  <- diag(mm.mono%*% tcrossprod(vcov(monomod), mm.mono))

cmult <- 1.96

newdat.poly <- data.frame(
  newdat.poly
  , pred.r = inv.logit(newdat.poly$pred)  
  , phi.r  = inv.logit(newdat.poly$pred+cmult*sqrt(pvar.poly))
  , plo.r  = inv.logit(newdat.poly$pred-cmult*sqrt(pvar.poly))
)

newdat.mono <- data.frame(
  newdat.mono
  , pred.r = inv.logit(newdat.mono$pred)  
  , phi.r  = inv.logit(newdat.mono$pred+cmult*sqrt(pvar.mono))
  , plo.r  = inv.logit(newdat.mono$pred-cmult*sqrt(pvar.mono))
)

#Helpful for plotting further down
newdat.poly$num <- c(1,2,4,5,7,8,10,11) 
newdat.mono$num <- c(1,2,4,5) 

#Make plot of predicted probability of sprouting according to vitality category and year for polycormic and monocormic trees (Fig 4a,b)
par(mar=c(0,0,0,0))
par(oma=c(4,4,4,4))
plot(newdat.poly$num,newdat.poly$pred.r,ylim=c(0,1),type="n",xlim=c(0,12),xaxt="n",las=1,tcl=0.3,cex.axis=1.1)
for(i in 0:3){ 
  arrows(x0=newdat.poly$num[newdat.poly$vit==i & newdat.poly$Period=="2010"],x1=newdat.poly$num[newdat.poly$vit==i & newdat.poly$Period=="2016"],
         y0=newdat.poly$pred.r[newdat.poly$vit==i & newdat.poly$Period=="2010"],y1=newdat.poly$pred.r[newdat.poly$vit==i & newdat.poly$Period=="2016"],
         length=0,lwd=1,col="black")}
errbar(x=newdat.poly$num,y=newdat.poly$pred.r,yplus=newdat.poly$phi.r,yminus=newdat.poly$plo.r,add=T,cap=0.00,lwd=1,cex=0)
points(newdat.poly$num,newdat.poly$pred.r,pch=21,cex=2.5,bg=c("white","grey") )
axis(1,at=c(1.5,4.5,7.5,10.5),labels=c("D","L1","L2","L3"),tcl=0.0,cex.axis=1.1)
mtext(side=2,"Probability of sprouting",outer=T,padj=-3.9,adj=0.5,cex=1.0)
mtext(side=1,"Vitality category",outer=T,padj=4,adj=0.5,cex=1.0)
mtext(side=3,"Polycormic",outer=T,padj=-0.5,adj=0.5,cex=1.0)

par(mar=c(0,0,0,0))
par(oma=c(4,4,4,4))
plot(newdat.mono$num,newdat.mono$pred.r,ylim=c(0,1),type="n",xlim=c(0,6),xaxt="n",las=1,tcl=0.3)
for(i in 0:3){ 
  arrows(x0=newdat.mono$num[newdat.mono$vit==i & newdat.mono$Period=="2010"],x1=newdat.mono$num[newdat.mono$vit==i & newdat.mono$Period=="2016"],
         y0=newdat.mono$pred.r[newdat.mono$vit==i & newdat.mono$Period=="2010"],y1=newdat.mono$pred.r[newdat.mono$vit==i & newdat.mono$Period=="2016"],
         length=0,lwd=1,col="black")}
errbar(x=newdat.mono$num,y=newdat.mono$pred.r,yplus=newdat.mono$phi.r,yminus=newdat.mono$plo.r,add=T,cap=0.00,lwd=1,cex=0)
points(newdat.mono$num,newdat.mono$pred.r,pch=21,cex=2.5,bg=c("white","grey") )
axis(2,labels=F,tcl=0.3)
axis(1,at=c(1.5,4.5),labels=c("D","L3"),tcl=0.0,cex.axis=1.1)
axis(2,labels=F,tcl=0.3)
mtext(side=2,"Probability of sprouting",outer=T,padj=-3.9,adj=0.5,cex=1.0)
mtext(side=1,"Vitality category",outer=T,padj=4,adj=0.5,cex=1.0)
mtext(side=3,"Monocormic",outer=T,padj=-0.5,adj=0.5,cex=1.0)


#######################################################################################
#######################################################################################
############ Proportion of trees that are dead and non-sprouting  #####################
#######################################################################################
#######################################################################################

#Fit binomial mixed model with the proportion dead/nonsprouting trees on the damage cluster*period interaction, with landscape blocks as random intercepts.
#Response is the number of trees with no sprouts and no living stems vs. all other outcomes with respect to sprouting and presence of living stems
basal.n.d.mod  <- glmer(cbind(basal.n.d,(basal.y.d + basal.n.l + basal.y.l)) ~ Period*dam.clust +(1|Block), binomial, data=for.stand, glmerControl(optimizer="bobyqa", optCtrl = list(maxfun = 10000000))) 

#Check for influential observations by sequential deletion of single observations
inf.basal.n.d <- influence(basal.n.d.mod,obs=TRUE)

#Check Coocks distance 
round(cooks.distance.estex(inf.basal.n.d),1)

#Which ovservations have large coocks (>1)?
which(cooks.distance.estex(inf.basal.n.d)>1)
#No observations are identified as influential

#Get parameter estimates. 95% CI presented in paper is taken as estimate +/- 1.96*SE
summary(basal.n.d.mod)

#Get back-transformed model predictions for, using the method suggested by Ben Bolker at http://bbolker.github.io/mixedmodels-misc/glmmFAQ.html for obtaining 95% CI. 
newdat.basal.n.d <- expand.grid(Period=unique(for.stand$Period),dam.clust=unique(for.stand$dam.clust),basal.y.l=0,basal.y.d=0,basal.n.l=0,basal.n.d=0)
mm.basal.n.d   <- model.matrix(terms(basal.n.d.mod),newdat.basal.n.d)
newdat.basal.n.d$pred.basal.n.d <- predict(basal.n.d.mod,newdat.basal.n.d, re.form=NA)
pvar.basal.n.d <- diag(mm.basal.n.d %*% tcrossprod(vcov(basal.n.d.mod), mm.basal.n.d))

cmult <- 1.96

newdat.basal.n.d <- data.frame(
  newdat.basal.n.d
  , pred.basal.n.d.r  = inv.logit(newdat.basal.n.d$pred.basal.n.d)
  , plo.basal.n.d.r   = inv.logit(newdat.basal.n.d$pred.basal.n.d-cmult*sqrt(pvar.basal.n.d))
  , phi.basal.n.d.r   = inv.logit(newdat.basal.n.d$pred.basal.n.d+cmult*sqrt(pvar.basal.n.d))
  , plo.basal.n.d.r   = inv.logit(newdat.basal.n.d$pred.basal.n.d-cmult*sqrt(pvar.basal.n.d))
  , phi.basal.n.d.r   = inv.logit(newdat.basal.n.d$pred.basal.n.d+cmult*sqrt(pvar.basal.n.d))
)

#Helps with plotting further down
newdat.basal.n.d$num <- c(4,5,1,2) 

#Proportion dead and non-sprouting per transect for plotting (raw data points)
for.stand$bas.n.d <- for.stand$basal.n.d/(for.stand$basal.y.l + for.stand$basal.n.l + for.stand$basal.y.d + for.stand$basal.n.d)

#Plot predictions and raw data (Fig. 4c)
par(mar=c(0,0,0,0))
par(oma=c(4,4,4,4))
plot(newdat.basal.n.d$num,newdat.basal.n.d$pred.basal.n.d.r,ylim=c(0,1),type="n",xlim=c(0,6),xaxt="n",las=1,tcl=0.3,cex.axis=1.1)
points(for.stand$num,jitter(for.stand$bas.n.d,0.5) ,pch=21,bg=for.stand$col,col="grey",cex=1.2)
for(i in 1:2){ 
  arrows(x0=newdat.basal.n.d$num[newdat.basal.n.d$dam.clust==dam.clust[i]  & newdat.basal.n.d$Period=="2010"],x1=newdat.basal.n.d$num[newdat.basal.n.d$dam.clust==dam.clust[i]  & newdat.basal.n.d$Period=="2016"],
         y0=newdat.basal.n.d$pred.basal.n.d.r[newdat.basal.n.d$dam.clust==dam.clust[i]  & newdat.basal.n.d$Period=="2010"],y1=newdat.basal.n.d$pred.basal.n.d.r[newdat.basal.n.d$dam.clust==dam.clust[i]  & newdat.basal.n.d$Period=="2016"],
         length=0,lwd=1,col="black")}
errbar(x=newdat.basal.n.d$num,y=newdat.basal.n.d$pred.basal.n.d.r,yplus=newdat.basal.n.d$phi.basal.n.d.r,yminus=newdat.basal.n.d$plo.basal.n.d.r,add=T,cap=0.00,lwd=1,cex=0)
points(newdat.basal.n.d$num,newdat.basal.n.d$pred.basal.n.d.r,pch=21,cex=2.5,bg=c("white","grey") )
axis(1,at=c(1.5,4.5),labels=c("Healthy","Damaged"),tcl=0.0,cex.axis=1.1)
mtext(side=2,"Proportion",outer=T,padj=-3.9,adj=0.5,cex=1.0)


#######################################################################################
#######################################################################################
##################################### Saplings ########################################
#######################################################################################
#######################################################################################

#Fit negative binomial mixed model of sapling counts on period*damage cluster interaction and random intercepts for landscape blocks 
#Fit with both healhy and damaged forest as reference level for convenient extraction of response ratio 2016/2010 further down
nb.sapl      <- glmer.nb(Sapl ~ Period*dam.clust    +(1|Block), data=for.stand, glmerControl(optimizer="bobyqa", optCtrl = list(maxfun = 10000000))) 
nb.sapl.rev  <- glmer.nb(Sapl ~ Period*dam.clust.re +(1|Block), data=for.stand, glmerControl(optimizer="bobyqa", optCtrl = list(maxfun = 10000000))) 

#Check for influential observations by sequential deletion of single observations
inf.sapl <- influence(nb.sapl,obs=TRUE)

#Check Coocks distance 
round(cooks.distance.estex(inf.sapl),1)

#Which ovservations have large coocks (>1)?
which(cooks.distance.estex(inf.sapl)>1)

#Check parameter estimates when removing the one influential observation
inf.sapl$alt.fixed[which(cooks.distance.estex(inf.sapl)>1),]

#Check if statistical significance changes when removing the one influential observation
sigtest(inf.sapl)$"Intercept"[which(cooks.distance.estex(inf.sapl)>1),3]
sigtest(inf.sapl)$"Period2016"[which(cooks.distance.estex(inf.sapl)>1),3]
sigtest(inf.sapl)$"dam.clustDamaged"[which(cooks.distance.estex(inf.sapl)>1),3]
sigtest(inf.sapl)$"Period2016:dam.clustDamaged"[which(cooks.distance.estex(inf.sapl)>1),3]

#Removing one rather influential observation would serve to lower the intercept (healthy forest, 2010) somewhat, with corresponding changes in the other 3 parameters   
#Inspecting this observation, it proves to be a rather high sapling count for 2010. 
#However, the count does not appear to be outside the natural range of variation of the system. Thus, we decide to retain this observation  
for.stand[259,]

#Get parameter estimates. 95% CI presented in paper is taken as estimate +/- 1.96*SE
summary(nb.sapl)

#Get back-transformed model predictions for, using the method suggested by Ben Bolker at http://bbolker.github.io/mixedmodels-misc/glmmFAQ.html for obtaining 95% CI. 
newdat.sapl <- expand.grid(Period=unique(for.stand$Period),dam.clust=unique(for.stand$dam.clust),Sapl=0)
mm.sapl   <- model.matrix(terms(nb.sapl), newdat.sapl)
newdat.sapl$pred.sapl <- predict(nb.sapl, newdat.sapl, re.form=NA)
pvar.sapl <- diag(mm.sapl %*% tcrossprod(vcov(nb.sapl), mm.sapl))

cmult <- 1.96

newdat.sapl <- data.frame(
  newdat.sapl
  , pred.sapl.r  = exp(newdat.sapl$pred.sapl)
  , plo.sapl.r   = exp(newdat.sapl$pred.sapl-cmult*sqrt(pvar.sapl))
  , phi.sapl.r   = exp(newdat.sapl$pred.sapl+cmult*sqrt(pvar.sapl))
)

#Helps with plotting further down
newdat.sapl$num <- c(4,5,1,2) 

#Make dataframe with oddsd ratios 2016/2010
resp.frame.sapl <- expand.grid(dam.clust = unique(for.stand$dam.clust))
resp.frame.sapl$num <- c(2,1)

resp.frame.sapl$resp     <- c(exp(summary(nb.sapl.rev)$coef[2,1]), exp(summary(nb.sapl)$coef[2,1]))
resp.frame.sapl$resp.plo <- c(exp(summary(nb.sapl.rev)$coef[2,1]-1.96*summary(nb.sapl.rev)$coef[2,2]), exp(summary(nb.sapl)$coef[2,1]-1.96*summary(nb.sapl)$coef[2,2]))
resp.frame.sapl$resp.phi <- c(exp(summary(nb.sapl.rev)$coef[2,1]+1.96*summary(nb.sapl.rev)$coef[2,2]), exp(summary(nb.sapl)$coef[2,1]+1.96*summary(nb.sapl)$coef[2,2]))

#Plot response ratios and predictions (Fig 5a, b)
par(mar=c(0,0,0,0))
par(oma=c(4,4,4,4))
plot(resp.frame.sapl$num,resp.frame.sapl$resp,type="n",xlim=c(0.5,2.5),xaxt="n",las=1,tcl=0.3,cex.axis=1.1,ylim=c(0,25))
errbar(x=resp.frame.sapl$num,y=resp.frame.sapl$resp,yplus=resp.frame.sapl$resp.phi,yminus=resp.frame.sapl$resp.plo,add=T,cap=0.00,lwd=1,cex=0)
points(resp.frame.sapl$num,resp.frame.sapl$resp,pch=21,cex=2.5,bg="black")
abline(1,0,lty=2,col="grey55")
mtext(side=2,"Response ratio",   outer=T,padj=-3.9,adj=0.5,cex=1.0)
axis(1,at=c(1,2),labels=c("Healthy","Damaged"),tcl=0.0,cex.axis=1.1)

par(mar=c(0,0,0,0))
par(oma=c(4,4,4,4))
plot(newdat.sapl$num,newdat.sapl$pred.sapl.r,ylim=c(0.9,275),type="n",xlim=c(0,6),xaxt="n",las=1,log="y",tcl=0.3,cex.axis=1.1)
points(for.stand$num,jitter(for.stand$Sapl,0.5) ,pch=21,bg=for.stand$col,col="grey",cex=1.2)
for(i in 1:2){ 
  arrows(x0=newdat.sapl$num[newdat.sapl$dam.clust==dam.clust[i] & newdat.sapl$Period=="2010"],x1=newdat.sapl$num[newdat.sapl$dam.clust==dam.clust[i] & newdat.sapl$Period=="2016"],
         y0=newdat.sapl$pred.sapl.r[newdat.sapl$dam.clust==dam.clust[i] & newdat.sapl$Period=="2010"]+1,y1=newdat.sapl$pred.sapl.r[newdat.sapl$dam.clust==dam.clust[i] & newdat.sapl$Period=="2016"]+1,
         length=0,lwd=1,col="black")}
errbar(x=newdat.sapl$num,y=newdat.sapl$pred.sapl.r+1,yplus=newdat.sapl$phi.sapl.r+1,yminus=newdat.sapl$plo.sapl.r+1,add=T,cap=0.00,lwd=1,cex=0)
points(newdat.sapl$num,newdat.sapl$pred.sapl.r+1,pch=21,cex=2.5,bg=c("white","grey") )
legend("topleft",pch=21,pt.bg=c("white","grey"),legend=c("2010","2016"),pt.cex=2.2)
mtext(side=2,"# saplings + 1",   outer=T,padj=-3.9,adj=0.5,cex=1.0)
axis(1,at=c(1.5,4.5),labels=c("Healthy","Damaged"),tcl=0.0,cex.axis=1.1)

#######################################################################################
#######################################################################################
############# Positive feedback between saplings and surviving trees  #################
#######################################################################################
#######################################################################################

#Counter for living trees. Define living trees as ones with at least one living stem and/or basal sprouts present (i.e. living root systems)
for.tree$L.tree <- ifelse(for.tree$all.live>0|for.tree$bas>0,1,0)

#Counter for all trees
for.tree$tree.counter <- 1

#Make sure that transects with no trees have zero trees
for.tree$L.tree[for.tree$Block.trans.per %in% zero] <- 0
for.tree$tree.counter[for.tree$Block.trans.per %in% zero] <- 0

#Aggregate to number of trees per transect
for.tree.stand <- aggregate(for.tree[,12:13],by=list(Period=for.tree$Period,Block=for.tree$Block,Transect=for.tree$Transect),FUN=sum,na.rm=T)

#Merge with stand level data on sapling counts
for.tree.stand <- merge(for.tree.stand,for.stand[,c(1:4,9,18)],by=c("Period","Block","Transect"))

#Trees per meter
for.tree.stand$Tree_m  <- for.tree.stand$tree.counter/for.tree.stand$Meters
for.tree.stand$Live_m  <- for.tree.stand$L.tree/for.tree.stand$Meters

#Multiply by transect length of 50 m to have trees per 100 square meters (i.e. a full sampling transect)
for.tree.stand$Tree_m <- for.tree.stand$Tree_m*50
for.tree.stand$Live_m  <- for.tree.stand$Live_m*50

#Unique identifier for each block*transect combination
for.tree.stand$Block.trans <- paste(for.tree.stand$Block,for.tree.stand$Transect)

#Subset to individual years. We are interested in total tree density in 2010 and living tree density in 2016.
for.tree.stand.16 <- subset(for.tree.stand, Period=="2016")
for.tree.stand.10 <- subset(for.tree.stand, Period=="2010")

#Name relevant variables according to year
for.tree.stand.10$Tree_m.10 <- for.tree.stand.10$Tree_m
for.tree.stand.16$Sapl.16   <- for.tree.stand.16$Sapl
for.tree.stand.16$Live_m.16 <- for.tree.stand.16$Live_m

#Add sapling counts and live trees in 2016 to 2010 dataframe 
for.tree.stand.sap <- merge(for.tree.stand.10,for.tree.stand.16[,c(11:13)],)

#Fit model with sapling count as a function of living tree density. Block as random intercept
nb.sap.m  <- glmer.nb(Sapl.16 ~ poly(Live_m.16,2) + poly(Tree_m.10,2) +(1|Block), data=for.tree.stand.sap, glmerControl(optimizer="bobyqa", optCtrl = list(maxfun = 10000000))) 

#Check for influential observations by sequential deletion of single observations
inf.sap.m <- influence(nb.sap.m,obs=T)

#Check Coocks distance 
round(cooks.distance.estex(inf.sap.m),1)

#Which ovservations have large coocks (>1)?
which(cooks.distance.estex(inf.sap.m)>1)

#Check parameter estimates when removing the the influential observations
inf.sap.m$alt.fixed[which(cooks.distance.estex(inf.sap.m)>1),]

#Compare with parameter estimates including all observations
summary(nb.sap.m)

#It is clear that observation 16 has an extremely large influence on the estimate of the polynomial term for living tree density in 2016
#Inspecting this observation, we find that it is a rather extreme outlier, in the sense that it has a tree-density that is more than twice as high as any other transect 
#As a result, it pulls very strongly at the extreme end of the regression and alters the estimates completly. 
for.tree.stand.sap[16,]
for.tree.stand.sap$Live_m.16[order(for.tree.stand.sap$Live_m.16)]
plot(for.tree.stand.sap$Live_m.16)

#Refit the model without outlier
for.tree.stand.sap.2 <- for.tree.stand.sap[-c(16),]
nb.sap.m.2  <- glmer.nb(Sapl.16 ~ poly(Live_m.16,2) + poly(Tree_m.10,2) +(1|Block), data=for.tree.stand.sap.2, glmerControl(optimizer="bobyqa", optCtrl = list(maxfun = 10000000))) 

#Determine influence of single observations again
inf.sap.m.2 <- influence(nb.sap.m.2,obs=T)

#Check Coocks distance 
round(cooks.distance.estex(inf.sap.m.2),1)

#A number of observations now come out with high coocks distance, perhaps unsurpsisingly, given the large amounts of noise and many zeros in the sapling data. 
inf.sap.m.2$alt.fixed[which(cooks.distance.estex(inf.sap.m.2)>1),]
summary(nb.sap.m.2)
#Observation 147 appears to distort the parameter estimates for the initial tree density considerably. 

#As for live tree density above, this observation is a strange outlier, with almost twice as many trees as any other stand.
for.tree.stand.sap.2[147,]

#Again, it seems most reasonable to remove this observation, and not try to generalize to extremely dense stands.

#Refit the model without outlier
for.tree.stand.sap.3 <- for.tree.stand.sap.2[-c(147),]
nb.sap.m.3  <- glmer.nb(Sapl.16 ~ poly(Live_m.16,2) + poly(Tree_m.10,2) +(1|Block), data=for.tree.stand.sap.3, glmerControl(optimizer="bobyqa", optCtrl = list(maxfun = 10000000))) 

#Determine influence of single observations again
inf.sap.m.3 <- influence(nb.sap.m.3,obs=T)

#Check Coocks distance 
round(cooks.distance.estex(inf.sap.m.3),1)

#Check effect on parameter estimates again 
inf.sap.m.3$alt.fixed[which(cooks.distance.estex(inf.sap.m.3)>1),]

#Get parameter estimates. 95% CI presented in paper is taken as estimate +/- 1.96*SE
summary(nb.sap.m.3)

#Several observations with large coocks distance, but parameter estimates seem stable, so no further observations are considered for removal.

#Get back-transformed model predictions for, using the method suggested by Ben Bolker at http://bbolker.github.io/mixedmodels-misc/glmmFAQ.html for obtaining 95% CI. 
#Predict across the whole gradient of live tree density, holding initial tree density constant at its mean.
newdat.sap.m.3 <- expand.grid(Live_m.16=seq(0,30,0.5),Tree_m.10=mean(for.tree.stand.sap.3$Tree_m.10,na.rm=T), Sapl.16=0)
mm.sap.m.3   <- model.matrix(terms(nb.sap.m.3), newdat.sap.m.3)
newdat.sap.m.3$pred.sap.m <- predict(nb.sap.m.3, newdat.sap.m.3, re.form=NA)
pvar.sap.m <- diag(mm.sap.m.3 %*% tcrossprod(vcov(nb.sap.m.3), mm.sap.m.3))

cmult <- 1.96

newdat.sap.m.3 <- data.frame(
  newdat.sap.m.3
  , pred.sap.m.r  = exp(newdat.sap.m.3$pred.sap.m)
  , plo.sap.m.r   = exp(newdat.sap.m.3$pred.sap.m-cmult*sqrt(pvar.sap.m))
  , phi.sap.m.r   = exp(newdat.sap.m.3$pred.sap.m+cmult*sqrt(pvar.sap.m))
)

win.graph(3.9,8)
par(mfrow=c(2,1))
par(mar=c(5,4,1,1))

par(mar=c(0,0,0,0))
par(oma=c(4,4,4,4))
for.tree.stand.sap.3$dam.col <- ifelse(for.tree.stand.sap.3$dam.clust=="Damaged","grey","white")
plot(for.tree.stand.sap.3$Live_m.16,for.tree.stand.sap.3$Sapl+1,ylim=c(0.9,250),
     ylab="# saplings + 1",xlab="Tree density",las=1,log="y",type="n",tcl=0.2)
polygon(c(newdat.sap.m.3$Live_m.16,rev(newdat.sap.m.3$Live_m.16)),c((newdat.sap.m.3$phi.sap.m.r+1),rev((newdat.sap.m.3$plo.sap.m.r+1))),col="grey90",border=NA)
points(for.tree.stand.sap.3$Live_m.16,jitter((for.tree.stand.sap.3$Sapl.16+1),0.2) ,cex=1.0,pch=21,bg=for.tree.stand.sap.3$dam.col)
lines(newdat.sap.m.3$Live_m.16, newdat.sap.m.3$pred.sap.m.r+1,lwd=2)





